getPrisma: Create Prisma
These functions create a PRISMA diagram from a simple dataframe keeping track of sources and filters
It creates a DiagrammeR file run by grV
Description
Create Prisma
These functions create a PRISMA diagram from a simple dataframe keeping track of sources and filters
It creates a DiagrammeR file run by grV